@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.4.0';
+$Geo::Address::Formatter::VERSION = '1.3';
 use strict;
 use warnings;
 
@@ -15,7 +15,6 @@ use Try::Tiny;
 use YAML qw(Load LoadFile);
 
 my $THC = Text::Hogan::Compiler->new;
-my %THT_cache; # a place to store Text::Hogan::Template objects
 
 
 sub new {
@@ -55,6 +54,7 @@ sub _read_configuration {
         };
     }
 
+
     try {
         my @c = LoadFile($path . '/components.yaml');
 
@@ -122,7 +122,6 @@ sub format_address {
         }
         # no fallback
     }
-    $template_text =~ s/\n/, /sg;
 
     #print STDERR "t text " . Dumper $template_text;
 
@@ -135,17 +134,10 @@ sub format_address {
     if (scalar(@$ra_unknown)){
         $rh_components->{attention} = join(', ', map { $rh_components->{$_} } @$ra_unknown);
     }
-    # warn Dumper $rh_components;
-
-
-    # get a compiled template
-    if (!defined($THT_cache{$template_text})){
-        $THT_cache{$template_text} = $THC->compile($template_text, {'numeric_string_as_string' => 1});
-    } 
-    my $compiled_template = $THT_cache{$template_text};
 
+    #warn Dumper $rh_components;
     # render it
-    my $text = $self->_render_template($compiled_template, $rh_components);
+    my $text = $self->_render_template($template_text, $rh_components);
     $text = $self->_postformat($text,$rh_config->{postformat_replace});
     $text = $self->_clean($text);
     return $text;
@@ -269,9 +261,9 @@ sub _clean {
 }
 
 sub _render_template {
-    my $self       = shift;
-    my $THTemplate = shift;
-    my $components = shift;
+    my $self             = shift;
+    my $template_content = shift;
+    my $components       = shift;
 
     # Mustache calls it context
     my $context = clone($components);
@@ -281,13 +273,14 @@ sub _render_template {
         my $selected = first { length($_) } split(/\s*\|\|\s*/, $newtext);
         return $selected;
     };
-    
-    my $output = $THTemplate->render($context);
+
+    $template_content =~ s/\n/, /sg;
+    my $output = $THC->compile($template_content, {'numeric_string_as_string' => 1})->render($context);
     $output = $self->_clean($output);
 
     # is it empty?
     if ($output !~ m/\w/){
-        my @comps = keys %$components;
+        my @comps =  keys %$components;
         if (scalar(@comps) == 1){  
             foreach my $k (@comps){
                 $output = $components->{$k};
@@ -324,7 +317,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.4.0
+version 1.3
 
 =head1 SYNOPSIS
 
